#
# spec file for package python-websockets
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
Name:           python-websockets
Version:        8.1
Release:        bp155.2.12
Summary:        An implementation of the WebSocket Protocol (RFC 6455)
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/aaugustin/websockets
Source:         https://github.com/aaugustin/websockets/archive/%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Suggests:       python-asyncio
%python_subpackages

%description
WebSockets is a library for developing WebSocket servers_ and clients_ in
Python. It implements RFC 6455 with a focus on correctness and simplicity.
It passes the Autobahn Testsuite.

Built on top of Python's asynchronous I/O support introduced in PEP 3156,
it provides an API based on coroutines, making it easy to write highly
concurrent applications.

%prep
%setup -q -n websockets-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# Test execution speed depends on BS load and architecture, relax
export WEBSOCKETS_TESTS_TIMEOUT_FACTOR=5
%python_expand PYTHONPATH=%{buildroot}%{$python_sitearch} $python -m unittest

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitearch}/websockets
%{python_sitearch}/websockets-%{version}-py*.egg-info

%changelog
* Thu Feb  6 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 8.1
  * Added compatibility with Python 3.8.
- drop upstreamed patch python38-support.patch
* Wed Oct 16 2019 Steve Kowalik <steven.kowalik@suse.com>
- Add python38-support.patch from upstream that fixes build failures
  against Python 3.8.
* Tue Aug 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 8.0.2:
  * Restored the ability to pass a socket with the sock parameter of :func:`~server.serve`.
  * Removed an incorrect assertion when a connection drops.
* Mon Jul 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 8.0.1:
  * Version 8.0 drops compatibility with Python 3.4 and 3.5.
  * Various fixes
* Tue Apr 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 7.0:
  * Various fixes
  * Repository layout changes
* Mon Oct  1 2018 Tomáš Chvátal <tchvatal@suse.com>
- Call the tests the same way as upstream to avoid import cycles
* Mon Sep 24 2018 Tomáš Chvátal <tchvatal@suse.com>
- Do make sure to error out on test failure.
* Wed Aug 29 2018 tchvatal@suse.com
- Version update to 6.0:
  * compatibility with python 3.6
* Wed Jun 27 2018 abergmann@suse.com
- Update to version 5.0.1
  * CVE-2018-1000518: Defend against zip bombs (boo#1099269).
* Sat Oct  7 2017 stefan.bruens@rwth-aachen.de
- Add WEBSOCKETS_TESTS_TIMEOUT_FACTOR=5, otherwise tests in several
  projects fail
* Thu Sep  7 2017 toddrme2178@gmail.com
- initial version
